==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SensitivityLabelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.SensitivityLabelArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.SensitivityLabelRank
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A sensitivity label.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Updates the sensitivity label of a given column with all parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sensitivityLabel = new AzureNative.Sql.SensitivityLabel("sensitivityLabel", new()
 *     {
 *         ColumnName = "myColumn",
 *         DatabaseName = "myDatabase",
 *         InformationType = "PhoneNumber",
 *         InformationTypeId = "d22fa6e9-5ee4-3bde-4c2b-a409604c4646",
 *         LabelId = "bf91e08c-f4f0-478a-b016-25164b2a65ff",
 *         LabelName = "PII",
 *         Rank = AzureNative.Sql.SensitivityLabelRank.Low,
 *         ResourceGroupName = "myRG",
 *         SchemaName = "dbo",
 *         SensitivityLabelSource = "current",
 *         ServerName = "myServer",
 *         TableName = "myTable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSensitivityLabel(ctx, "sensitivityLabel", &sql.SensitivityLabelArgs{
 * 			ColumnName:             pulumi.String("myColumn"),
 * 			DatabaseName:           pulumi.String("myDatabase"),
 * 			InformationType:        pulumi.String("PhoneNumber"),
 * 			InformationTypeId:      pulumi.String("d22fa6e9-5ee4-3bde-4c2b-a409604c4646"),
 * 			LabelId:                pulumi.String("bf91e08c-f4f0-478a-b016-25164b2a65ff"),
 * 			LabelName:              pulumi.String("PII"),
 * 			Rank:                   sql.SensitivityLabelRankLow,
 * 			ResourceGroupName:      pulumi.String("myRG"),
 * 			SchemaName:             pulumi.String("dbo"),
 * 			SensitivityLabelSource: pulumi.String("current"),
 * 			ServerName:             pulumi.String("myServer"),
 * 			TableName:              pulumi.String("myTable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SensitivityLabel;
 * import com.pulumi.azurenative.sql.SensitivityLabelArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sensitivityLabel = new SensitivityLabel("sensitivityLabel", SensitivityLabelArgs.builder()
 *             .columnName("myColumn")
 *             .databaseName("myDatabase")
 *             .informationType("PhoneNumber")
 *             .informationTypeId("d22fa6e9-5ee4-3bde-4c2b-a409604c4646")
 *             .labelId("bf91e08c-f4f0-478a-b016-25164b2a65ff")
 *             .labelName("PII")
 *             .rank("Low")
 *             .resourceGroupName("myRG")
 *             .schemaName("dbo")
 *             .sensitivityLabelSource("current")
 *             .serverName("myServer")
 *             .tableName("myTable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SensitivityLabel current /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/schemas/{schemaName}/tables/{tableName}/columns/{columnName}/sensitivityLabels/{sensitivityLabelSource}
 * ```
 * @property columnName The name of the column.
 * @property databaseName The name of the database.
 * @property informationType The information type.
 * @property informationTypeId The information type ID.
 * @property labelId The label ID.
 * @property labelName The label name.
 * @property rank
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property schemaName The name of the schema.
 * @property sensitivityLabelSource The source of the sensitivity label.
 * @property serverName The name of the server.
 * @property tableName The name of the table.
 */
public data class SensitivityLabelArgs(
    public val columnName: Output<String>? = null,
    public val databaseName: Output<String>? = null,
    public val informationType: Output<String>? = null,
    public val informationTypeId: Output<String>? = null,
    public val labelId: Output<String>? = null,
    public val labelName: Output<String>? = null,
    public val rank: Output<SensitivityLabelRank>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val schemaName: Output<String>? = null,
    public val sensitivityLabelSource: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val tableName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.SensitivityLabelArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.SensitivityLabelArgs =
        com.pulumi.azurenative.sql.SensitivityLabelArgs.builder()
            .columnName(columnName?.applyValue({ args0 -> args0 }))
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .informationType(informationType?.applyValue({ args0 -> args0 }))
            .informationTypeId(informationTypeId?.applyValue({ args0 -> args0 }))
            .labelId(labelId?.applyValue({ args0 -> args0 }))
            .labelName(labelName?.applyValue({ args0 -> args0 }))
            .rank(rank?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .schemaName(schemaName?.applyValue({ args0 -> args0 }))
            .sensitivityLabelSource(sensitivityLabelSource?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .tableName(tableName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SensitivityLabelArgs].
 */
@PulumiTagMarker
public class SensitivityLabelArgsBuilder internal constructor() {
    private var columnName: Output<String>? = null

    private var databaseName: Output<String>? = null

    private var informationType: Output<String>? = null

    private var informationTypeId: Output<String>? = null

    private var labelId: Output<String>? = null

    private var labelName: Output<String>? = null

    private var rank: Output<SensitivityLabelRank>? = null

    private var resourceGroupName: Output<String>? = null

    private var schemaName: Output<String>? = null

    private var sensitivityLabelSource: Output<String>? = null

    private var serverName: Output<String>? = null

    private var tableName: Output<String>? = null

    /**
     * @param value The name of the column.
     */
    @JvmName("dxpjjvpeyiknbtwj")
    public suspend fun columnName(`value`: Output<String>) {
        this.columnName = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("nelmwwntiwvunyxc")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The information type.
     */
    @JvmName("opimpatjhkkdikbo")
    public suspend fun informationType(`value`: Output<String>) {
        this.informationType = value
    }

    /**
     * @param value The information type ID.
     */
    @JvmName("wkmjwmwmjybljdjs")
    public suspend fun informationTypeId(`value`: Output<String>) {
        this.informationTypeId = value
    }

    /**
     * @param value The label ID.
     */
    @JvmName("eixauhqkqrguiqlv")
    public suspend fun labelId(`value`: Output<String>) {
        this.labelId = value
    }

    /**
     * @param value The label name.
     */
    @JvmName("pjgowsxwkqbpecpj")
    public suspend fun labelName(`value`: Output<String>) {
        this.labelName = value
    }

    /**
     * @param value
     */
    @JvmName("iqpjdwnpusavjxxe")
    public suspend fun rank(`value`: Output<SensitivityLabelRank>) {
        this.rank = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("eccmcusrfkvbrunr")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the schema.
     */
    @JvmName("jiwaeraivcblwytx")
    public suspend fun schemaName(`value`: Output<String>) {
        this.schemaName = value
    }

    /**
     * @param value The source of the sensitivity label.
     */
    @JvmName("otufxenfvykgjrlc")
    public suspend fun sensitivityLabelSource(`value`: Output<String>) {
        this.sensitivityLabelSource = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("mxgfaeqecmbkwiyi")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The name of the table.
     */
    @JvmName("huuijrekcphicxdo")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value The name of the column.
     */
    @JvmName("yoievhypndfvrbgj")
    public suspend fun columnName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columnName = mapped
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("vljqqoudpvttswkf")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The information type.
     */
    @JvmName("fagcwueyjlclbify")
    public suspend fun informationType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.informationType = mapped
    }

    /**
     * @param value The information type ID.
     */
    @JvmName("uaxuggfdwnqwbjoe")
    public suspend fun informationTypeId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.informationTypeId = mapped
    }

    /**
     * @param value The label ID.
     */
    @JvmName("grrijttlvdcxqvah")
    public suspend fun labelId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelId = mapped
    }

    /**
     * @param value The label name.
     */
    @JvmName("ueexyksgqkxqelfm")
    public suspend fun labelName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelName = mapped
    }

    /**
     * @param value
     */
    @JvmName("jwgmjwevbsugqdhp")
    public suspend fun rank(`value`: SensitivityLabelRank?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rank = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("mauvkghdhntmkmvd")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the schema.
     */
    @JvmName("omktuommkgvtuqbp")
    public suspend fun schemaName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaName = mapped
    }

    /**
     * @param value The source of the sensitivity label.
     */
    @JvmName("gyidsxcwbpavqpcl")
    public suspend fun sensitivityLabelSource(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sensitivityLabelSource = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("jknxyovqitcculha")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The name of the table.
     */
    @JvmName("tirjeabccemhpklh")
    public suspend fun tableName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    internal fun build(): SensitivityLabelArgs = SensitivityLabelArgs(
        columnName = columnName,
        databaseName = databaseName,
        informationType = informationType,
        informationTypeId = informationTypeId,
        labelId = labelId,
        labelName = labelName,
        rank = rank,
        resourceGroupName = resourceGroupName,
        schemaName = schemaName,
        sensitivityLabelSource = sensitivityLabelSource,
        serverName = serverName,
        tableName = tableName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SensitivityLabelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.SensitivityLabelArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.SensitivityLabelRank
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A sensitivity label.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Updates the sensitivity label of a given column with all parameters
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sensitivityLabel = new AzureNative.Sql.SensitivityLabel("sensitivityLabel", new()
 *     {
 *         ColumnName = "myColumn",
 *         DatabaseName = "myDatabase",
 *         InformationType = "PhoneNumber",
 *         InformationTypeId = "d22fa6e9-5ee4-3bde-4c2b-a409604c4646",
 *         LabelId = "bf91e08c-f4f0-478a-b016-25164b2a65ff",
 *         LabelName = "PII",
 *         Rank = AzureNative.Sql.SensitivityLabelRank.Low,
 *         ResourceGroupName = "myRG",
 *         SchemaName = "dbo",
 *         SensitivityLabelSource = "current",
 *         ServerName = "myServer",
 *         TableName = "myTable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSensitivityLabel(ctx, "sensitivityLabel", &sql.SensitivityLabelArgs{
 * 			ColumnName:             pulumi.String("myColumn"),
 * 			DatabaseName:           pulumi.String("myDatabase"),
 * 			InformationType:        pulumi.String("PhoneNumber"),
 * 			InformationTypeId:      pulumi.String("d22fa6e9-5ee4-3bde-4c2b-a409604c4646"),
 * 			LabelId:                pulumi.String("bf91e08c-f4f0-478a-b016-25164b2a65ff"),
 * 			LabelName:              pulumi.String("PII"),
 * 			Rank:                   sql.SensitivityLabelRankLow,
 * 			ResourceGroupName:      pulumi.String("myRG"),
 * 			SchemaName:             pulumi.String("dbo"),
 * 			SensitivityLabelSource: pulumi.String("current"),
 * 			ServerName:             pulumi.String("myServer"),
 * 			TableName:              pulumi.String("myTable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SensitivityLabel;
 * import com.pulumi.azurenative.sql.SensitivityLabelArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sensitivityLabel = new SensitivityLabel("sensitivityLabel", SensitivityLabelArgs.builder()
 *             .columnName("myColumn")
 *             .databaseName("myDatabase")
 *             .informationType("PhoneNumber")
 *             .informationTypeId("d22fa6e9-5ee4-3bde-4c2b-a409604c4646")
 *             .labelId("bf91e08c-f4f0-478a-b016-25164b2a65ff")
 *             .labelName("PII")
 *             .rank("Low")
 *             .resourceGroupName("myRG")
 *             .schemaName("dbo")
 *             .sensitivityLabelSource("current")
 *             .serverName("myServer")
 *             .tableName("myTable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SensitivityLabel current /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/schemas/{schemaName}/tables/{tableName}/columns/{columnName}/sensitivityLabels/{sensitivityLabelSource}
 * ```
 * @property columnName The name of the column.
 * @property databaseName The name of the database.
 * @property informationType The information type.
 * @property informationTypeId The information type ID.
 * @property labelId The label ID.
 * @property labelName The label name.
 * @property rank
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property schemaName The name of the schema.
 * @property sensitivityLabelSource The source of the sensitivity label.
 * @property serverName The name of the server.
 * @property tableName The name of the table.
 */
public data class SensitivityLabelArgs(
    public val columnName: Output<String>? = null,
    public val databaseName: Output<String>? = null,
    public val informationType: Output<String>? = null,
    public val informationTypeId: Output<String>? = null,
    public val labelId: Output<String>? = null,
    public val labelName: Output<String>? = null,
    public val rank: Output<SensitivityLabelRank>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val schemaName: Output<String>? = null,
    public val sensitivityLabelSource: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val tableName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.SensitivityLabelArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.SensitivityLabelArgs =
        com.pulumi.azurenative.sql.SensitivityLabelArgs.builder()
            .columnName(columnName?.applyValue({ args0 -> args0 }))
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .informationType(informationType?.applyValue({ args0 -> args0 }))
            .informationTypeId(informationTypeId?.applyValue({ args0 -> args0 }))
            .labelId(labelId?.applyValue({ args0 -> args0 }))
            .labelName(labelName?.applyValue({ args0 -> args0 }))
            .rank(rank?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .schemaName(schemaName?.applyValue({ args0 -> args0 }))
            .sensitivityLabelSource(sensitivityLabelSource?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .tableName(tableName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SensitivityLabelArgs].
 */
@PulumiTagMarker
public class SensitivityLabelArgsBuilder internal constructor() {
    private var columnName: Output<String>? = null

    private var databaseName: Output<String>? = null

    private var informationType: Output<String>? = null

    private var informationTypeId: Output<String>? = null

    private var labelId: Output<String>? = null

    private var labelName: Output<String>? = null

    private var rank: Output<SensitivityLabelRank>? = null

    private var resourceGroupName: Output<String>? = null

    private var schemaName: Output<String>? = null

    private var sensitivityLabelSource: Output<String>? = null

    private var serverName: Output<String>? = null

    private var tableName: Output<String>? = null

    /**
     * @param value The name of the column.
     */
    @JvmName("tcvwtunnidbrpekc")
    public suspend fun columnName(`value`: Output<String>) {
        this.columnName = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("wgxorulgbkxsfdto")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The information type.
     */
    @JvmName("xaxuulvooghwwskk")
    public suspend fun informationType(`value`: Output<String>) {
        this.informationType = value
    }

    /**
     * @param value The information type ID.
     */
    @JvmName("thdmnblhkmskckgb")
    public suspend fun informationTypeId(`value`: Output<String>) {
        this.informationTypeId = value
    }

    /**
     * @param value The label ID.
     */
    @JvmName("hpacrtcvbyftvbib")
    public suspend fun labelId(`value`: Output<String>) {
        this.labelId = value
    }

    /**
     * @param value The label name.
     */
    @JvmName("pdrosjrgfhyomvwc")
    public suspend fun labelName(`value`: Output<String>) {
        this.labelName = value
    }

    /**
     * @param value
     */
    @JvmName("wdxwpwiwfjapxeww")
    public suspend fun rank(`value`: Output<SensitivityLabelRank>) {
        this.rank = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("pjosbtvfnvrvghgv")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the schema.
     */
    @JvmName("adywfrksycneyxdv")
    public suspend fun schemaName(`value`: Output<String>) {
        this.schemaName = value
    }

    /**
     * @param value The source of the sensitivity label.
     */
    @JvmName("rcvwecpxbcbbkdll")
    public suspend fun sensitivityLabelSource(`value`: Output<String>) {
        this.sensitivityLabelSource = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("trsuowvgmiqmwdcr")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The name of the table.
     */
    @JvmName("fvxopblcrsbixkjk")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value The name of the column.
     */
    @JvmName("duxbuefcqsnxpbep")
    public suspend fun columnName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columnName = mapped
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("vhwtmnnybbxnvfyj")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The information type.
     */
    @JvmName("tvmcmafmxggmqnyi")
    public suspend fun informationType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.informationType = mapped
    }

    /**
     * @param value The information type ID.
     */
    @JvmName("vvvdkdytrgvwvdeb")
    public suspend fun informationTypeId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.informationTypeId = mapped
    }

    /**
     * @param value The label ID.
     */
    @JvmName("puarenkbtfeoknst")
    public suspend fun labelId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelId = mapped
    }

    /**
     * @param value The label name.
     */
    @JvmName("kbuyjjtvnusfsvsp")
    public suspend fun labelName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelName = mapped
    }

    /**
     * @param value
     */
    @JvmName("oadebvilpgadxonv")
    public suspend fun rank(`value`: SensitivityLabelRank?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rank = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("heitdsnwtoyufpcu")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the schema.
     */
    @JvmName("erheesffunoqmomq")
    public suspend fun schemaName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaName = mapped
    }

    /**
     * @param value The source of the sensitivity label.
     */
    @JvmName("qmxkpdnwdpmisvup")
    public suspend fun sensitivityLabelSource(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sensitivityLabelSource = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("aewhekfmcfupjbyo")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The name of the table.
     */
    @JvmName("fxeptqbfpswukuuw")
    public suspend fun tableName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    internal fun build(): SensitivityLabelArgs = SensitivityLabelArgs(
        columnName = columnName,
        databaseName = databaseName,
        informationType = informationType,
        informationTypeId = informationTypeId,
        labelId = labelId,
        labelName = labelName,
        rank = rank,
        resourceGroupName = resourceGroupName,
        schemaName = schemaName,
        sensitivityLabelSource = sensitivityLabelSource,
        serverName = serverName,
        tableName = tableName,
    )
}
